﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MontoyaTech.MySqlPlus
{
    /// <summary>
    /// The outline of a MySqlRowIndex attribute which allows the specification
    /// of an index for a row.
    /// </summary>
    [AttributeUsage(AttributeTargets.Class | AttributeTargets.Struct, AllowMultiple = true, Inherited = true)]
    public class MySqlRowIndex : Attribute
    {
        /// <summary>
        /// The name of this index.
        /// </summary>
        public string Name;

        /// <summary>
        /// The name of the columns that belong to this index.
        /// </summary>
        public string[] Columns;

        /// <summary>
        /// Creates a new default MySqlRowIndex.
        /// </summary>
        public MySqlRowIndex() { }

        /// <summary>
        /// Creates a new default MySqlRowIndex with a name and column names.
        /// </summary>
        /// <param name="name"></param>
        /// <param name="columns"></param>
        /// <exception cref="ArgumentException"></exception>
        public MySqlRowIndex(string name, params string[] columns)
        {
            if (columns == null || columns.Length == 0)
                throw new ArgumentException("Columns must not be null or 0.");

            this.Name = name;

            this.Columns = columns;
        }
    }
}
